IosDevices class

A set of iOS devices.

Constructors

IosDevices()
const

Properties

all → List<DeviceInfo>
All devices.
no setter
hashCode → int
The hash code for this object.
no setterinherited
iPad12InchesGen2 → DeviceInfo
no setter
iPad12InchesGen4 → DeviceInfo
no setter
iPadAir4 → DeviceInfo
no setter
iPadPro11Inches → DeviceInfo
no setter
iPhone12 → DeviceInfo
no setter
iPhone12Mini → DeviceInfo
no setter
iPhone12ProMax → DeviceInfo
no setter
iPhone13 → DeviceInfo
no setter
iPhone13Mini → DeviceInfo
no setter
iPhone13ProMax → DeviceInfo
no setter
iPhone14Pro → DeviceInfo
no setter
iPhoneSE → DeviceInfo
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited