onHitTest property

HitTestCallback? get onHitTest
override

A callback invoked when the platform wants to hit test a FlutterView.

For example, this is used by iOS to determine if a gesture hits a UIKitView.

Implementation

get onHitTest => (parent as dynamic).onHitTest;
set onHitTest (dynamic callback)
override

Implementation

set onHitTest(dynamic callback) {
  (parent as dynamic).onHitTest = callback;
}