setApplicationLocale method

void setApplicationLocale(
  1. Locale locale
)
override

Sets the locale for the application in engine.

This is typically called by framework to set the locale based on which locale the Flutter app actually uses.

Implementation

void setApplicationLocale(Locale locale) {
  (parent as dynamic).setApplicationLocale(locale);
}