VirtualTransforms class abstract

Helps to correctly project a virtual screen on a real one.

Constructors

VirtualTransforms()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

globalDestinationRect(DeviceInfo device, Orientation orientation) → Rect
globalTransform(DeviceInfo device, Orientation orientation) → Matrix4
screenDestinationRect(DeviceInfo device, Orientation orientation) → Rect
screenScaleTransform(DeviceInfo device) → Matrix4
screenTranslate(DeviceInfo device, [bool inverted = false]) → Offset
screenTranslateTransform(DeviceInfo device, [bool inverted = false]) → Matrix4