VirtualViewConfiguration class

The layout constraints for the root render object.

Inheritance

Properties

devicePixelRatio ↔ double
The pixel density of the output surface.
getter/setter pairoverride-getter
hashCode → int
The hash code for this object.
no setterinherited
logicalConstraints ↔ BoxConstraints
The constraints of the output surface in logical pixel.
getter/setter pairoverride-getter
parent ↔ ViewConfiguration
Real ViewConfiguration.
getter/setter pair
physicalConstraints ↔ BoxConstraints
The constraints of the output surface in physical pixel.
getter/setter pairoverride-getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetAll() → void
Reset all configuration to real device.
resetDevicePixelRatios() → void
Reset configuration to real device pixel ratios.
resetLogicalConstraints() → void
Reset configuration to real device logical constraints.
resetPhysicalConstraints() → void
Reset configuration to real device physical constraints.
shouldUpdateMatrix(ViewConfiguration oldConfiguration) → bool
Returns whether toMatrix would return a different value for this configuration than it would for the given oldConfiguration.
override
toMatrix() → Matrix4
Creates a transformation matrix that applies the devicePixelRatio.
override
toPhysicalSize(Size logicalSize) → Size
Transforms the provided Size in logical pixels to physical pixels.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override