physicalConstraints property
The constraints of the output surface in physical pixel.
These constraints are enforced in toPhysicalSize when translating the logical size of the root render object back to physical pixels for the ui.FlutterView.render method.
Implementation
@override
BoxConstraints get physicalConstraints =>
_physicalConstraints ?? parent.physicalConstraints;
set
physicalConstraints
(BoxConstraints value)
Implementation
set physicalConstraints(BoxConstraints value) {
_physicalConstraints = value;
}