VirtualViewPadding class
A representation of distances for each of the four edges of a rectangle, used to encode the view insets and padding that applications should place around their user interface, as exposed by FlutterView.viewInsets and FlutterView.padding. View insets and padding are preferably read via MediaQuery.of.
- Implemented types
Constructors
- VirtualViewPadding({required double left, required double top, required double right, required double bottom})
-
const
- VirtualViewPadding.all(double value)
-
const
- VirtualViewPadding.fromEdgeInsets(EdgeInsets insets)
-
factory
Properties
- bottom → double
-
The distance from the bottom edge to the first unpadded pixel, in physical pixels.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- left → double
-
The distance from the left edge to the first unpadded pixel, in physical pixels.
final
- right → double
-
The distance from the right edge to the first unpadded pixel, in physical pixels.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → double
-
The distance from the top edge to the first unpadded pixel, in physical pixels.
final
Methods
-
asEdgeInsets(
) → EdgeInsets -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited