brieflyShowPassword property

  1. @Deprecated('Deprecated to prepare for the upcoming multi-window support. ' 'This feature was deprecated after v3.9.0-0.1.pre.')
  2. @override
bool get brieflyShowPassword
override

Whether briefly displaying the characters as you type in obscured text fields is enabled in system settings.

See also:

Implementation

@Deprecated('Deprecated to prepare for the upcoming multi-window support. '
    'This feature was deprecated after v3.9.0-0.1.pre.')
@override
bool get brieflyShowPassword => platformDispatcher.brieflyShowPassword;