supportsShowingSystemContextMenu property
- @Deprecated('Deprecated to prepare for the upcoming multi-window support. ' 'This feature was deprecated after v3.9.0-0.1.pre.')
- @override
override
Whether showing system context menu is supported on the current platform.
This option is used by AdaptiveTextSelectionToolbar to decide whether to show system context menu, or to fallback to the default Flutter context menu.
Implementation
@Deprecated(
'Deprecated to prepare for the upcoming multi-window support. '
'This feature was deprecated after v3.9.0-0.1.pre.',
)
@override
bool get supportsShowingSystemContextMenu =>
platformDispatcher.supportsShowingSystemContextMenu;