AndroidDevices class
A set of iOS devices.
Constructors
- AndroidDevices()
-
const
Properties
-
all
→ List<
DeviceInfo> -
All available devices.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- onePlus8Pro → DeviceInfo
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samsungGalaxyA50 → DeviceInfo
-
no setter
- samsungGalaxyNote20Ultra → DeviceInfo
-
no setter
- samsungGalaxyS20 → DeviceInfo
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited