VirtualDisplay class
A configurable display that a FlutterView renders on.
- Implemented types
Constructors
- VirtualDisplay(VirtualPlatformDispatcher platformDispatcher, Display display)
Properties
- devicePixelRatio ↔ double
-
The device pixel ratio of this display.
getter/setter pairoverride-getter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
A unique identifier for this display.
no setteroverride
- refreshRate ↔ double
-
The refresh rate in FPS of this display.
getter/setter pairoverride-getter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ↔ Size
-
The physical size of this display.
getter/setter pairoverride-getter
- vDevicePixelRatio ↔ double?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
bool notify) → void - Reset all display configuration to real device.
-
resetDevicePixelRatio(
bool notify) → void - Reset configuration to real device pixel ratio.
-
resetRefreshRate(
bool notify) → void - Reset configuration to real device refresh rate.
-
resetSize(
bool notify) → void - Reset configuration to real device size.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited