VirtualFlutterView class

A view into which a Flutter Scene is drawn.

Each FlutterView has its own layer tree that is rendered whenever render is called on it with a Scene.

References to FlutterView objects are obtained via the PlatformDispatcher.

Implemented types

Constructors

VirtualFlutterView({required FlutterView view, required VirtualPlatformDispatcher platformDispatcher, required VirtualDisplay display})

Properties

devicePixelRatio double
The number of device pixels for each logical pixel for the screen this view is displayed on.
getter/setter pairoverride-getter
display VirtualDisplay
The Display this view is drawn in.
no setteroverride
displayFeatures List<DisplayFeature>
Areas of the display that are obstructed by hardware features.
getter/setter pairoverride-getter
gestureSettings GestureSettings
Additional configuration for touch gestures performed on this view.
getter/setter pairoverride-getter
hashCode int
The hash code for this object.
no setterinherited
padding ViewPadding
The number of physical pixels on each side of the display rectangle into which the view can render, but which may be partially obscured by system UI (such as the system notification area), or physical intrusions in the display (e.g. overscan regions on television screens or phone sensor housings).
getter/setter pairoverride-getter
parent FlutterView
Real FlutterView.
final
parentInsets ViewPadding?
getter/setter pair
parentPadding ViewPadding?
getter/setter pair
physicalConstraints ViewConstraints
The sizing constraints in physical pixels for this view.
getter/setter pairoverride-getter
physicalSize Size
The current dimensions of the rectangle as last reported by the platform into which scenes rendered in this view are drawn.
getter/setter pairoverride-getter
platformDispatcher VirtualPlatformDispatcher
The platform dispatcher that this view is registered with, and gets its information from.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemGestureInsets ViewPadding
The number of physical pixels on each side of the display rectangle into which the view can render, but where the operating system will consume input gestures for the sake of system navigation.
getter/setter pairoverride-getter
viewId int
The opaque ID for this view.
no setteroverride
viewInsets ViewPadding
The number of physical pixels on each side of the display rectangle into which the view can render, but over which the operating system will likely place system UI, such as the keyboard, that fully obscures any content.
getter/setter pairoverride-getter
viewPadding ViewPadding
The number of physical pixels on each side of the display rectangle into which the view can render, but which may be partially obscured by system UI (such as the system notification area), or physical intrusions in the display (e.g. overscan regions on television screens or phone sensor housings).
getter/setter pairoverride-getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Scene scene, {Size? size}) → void
Updates the view's rendering on the GPU with the newly provided Scene.
override
reset({required bool notify}) → void
Reset all configuration to real device.
resetDevicePixelRatio(bool notify) → void
Reset configuration to real device pixel ratio.
resetDisplayFeatures(bool notify) → void
Reset configuration to real device display features.
resetGestureSettings(bool notify) → void
Reset configuration to real device gesture settings.
resetPadding(bool notify) → void
Reset configuration to real device padding.
resetPhysicalConstraints(bool notify) → void
Reset configuration to real device physical constraints.
resetPhysicalSize(bool notify) → void
Reset configuration to real device physical size.
resetSystemGestureInsets(bool notify) → void
Reset configuration to real device system gesture insets.
resetViewInsets(bool notify) → void
Reset configuration to real device view insets.
resetViewPadding(bool notify) → void
Reset configuration to real device view padding.
toString() String
A string representation of this object.
inherited
updateSemantics(SemanticsUpdate update) → void
Change the retained semantics data about this FlutterView.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited