supportsShowingSystemContextMenu property

  1. @Deprecated('Deprecated to prepare for the upcoming multi-window support. ' 'This feature was deprecated after v3.9.0-0.1.pre.')
  2. @override
bool get supportsShowingSystemContextMenu
override

Whether the spell check service is supported on the current platform.

This option is used by EditableTextState to define its SpellCheckConfiguration when a default spell check service is requested.

Implementation

@Deprecated(
  'Deprecated to prepare for the upcoming multi-window support. '
  'This feature was deprecated after v3.9.0-0.1.pre.',
)
@override
bool get supportsShowingSystemContextMenu =>
    platformDispatcher.supportsShowingSystemContextMenu;